Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1128)

Unified Diff: Source/core/layout/LayoutTreeAsText.h

Issue 1180573003: Add option to dump line box tree when dumping layout tree. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: pointers->references Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/layout/LayoutTreeAsText.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/LayoutTreeAsText.h
diff --git a/Source/core/layout/LayoutTreeAsText.h b/Source/core/layout/LayoutTreeAsText.h
index e065de6789c0ad5bd0e7437234d23f50849d7f99..814443c4fab149936efa7404cf35f055e3d97c0e 100644
--- a/Source/core/layout/LayoutTreeAsText.h
+++ b/Source/core/layout/LayoutTreeAsText.h
@@ -33,11 +33,12 @@
namespace blink {
class Color;
+class DeprecatedPaintLayer;
class Element;
class LayoutRect;
class LocalFrame;
class Node;
-class DeprecatedPaintLayer;
+class LayoutBlockFlow;
class LayoutObject;
class TextStream;
@@ -50,7 +51,8 @@ enum LayoutAsTextBehaviorFlags {
LayoutAsTextShowIDAndClass = 1 << 4, // Show id and class attributes
LayoutAsTextPrintingMode = 1 << 5, // Dump the tree in printing mode.
LayoutAsTextDontUpdateLayout = 1 << 6, // Don't update layout, to make it safe to call showLayerTree() from the debugger inside layout or painting code.
- LayoutAsTextShowLayoutState = 1 << 7 // Print the various 'needs layout' bits on layoutObjects.
+ LayoutAsTextShowLayoutState = 1 << 7, // Print the various 'needs layout' bits on layoutObjects.
+ LayoutAsTextShowLineTrees = 1 << 8 // Dump the line trees for each LayoutBlockFlow.
};
typedef unsigned LayoutAsTextBehavior;
@@ -66,6 +68,7 @@ class LayoutTreeAsText {
public:
static void writeLayoutObject(TextStream&, const LayoutObject&, LayoutAsTextBehavior);
static void writeLayers(TextStream&, const DeprecatedPaintLayer* rootLayer, DeprecatedPaintLayer*, const LayoutRect& paintDirtyRect, int indent = 0, LayoutAsTextBehavior = LayoutAsTextBehaviorNormal);
+static void writeLineBoxTree(TextStream&, const LayoutBlockFlow&, int indent = 0);
};
// Helper function shared with SVGLayoutTreeAsText
« no previous file with comments | « no previous file | Source/core/layout/LayoutTreeAsText.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698